<?php
/**
 * @package CATS_JobSite
 * @author Andrew P. Kandels
 * @copyright 2009 - 2010 CATS Software, Inc.
 *
 * Template Class
 *
 * Loads and generates browser output (typically XHTML) and
 * maintains generated variables for output typically assigned
 * by a controller.
 *
 * This file is part of CATS JobSite.
 *
 * Copyright (C) 2009 - 2010 CATS Software, Inc.
 *
 * CATS JobSite is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * CATS JobSite is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with CATS JobSite in a file named "COPYING" in the root directory.
 * If not, see <http://www.gnu.org/licenses/>.
 */


class CATS_Template
{
    public function __construct()
    {
    }

    /**
     * Assigns a variable which can be referenced by the displayed
     * template during output.
     *
     * @param   string      Name of the variable
     * @param   mixed       Value
     * @return  void
     */
    public function assign($name, $value)
    {
        $this->$name = $value;
    }

    /**
     * Called from within the template during output to echo a
     * string safely, escaping any XHTML reserved characters with
     * entities.
     *
     * @param   string      Text to be echoed
     * @return  void
     */
    private function _($text)
    {
        echo htmlspecialchars($text);
    }

    /**
     * Loads a template (usually a file ending in .tpl.php) which can
     * include valid XHTML and optional embedded PHP inline source code.
     *
     * @param   string      Path to file
     * @return  void
     */
    public function display($file)
    {
        if (!file_exists($file))
        {
            throw new CATS_E_NOTEMPLATE();
        }

        include($file);
    }
}
